package com.zehong.system.service.impl;

import java.util.List;
import com.zehong.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.TUserInspectMapper;
import com.zehong.system.domain.TUserInspect;
import com.zehong.system.service.ITUserInspectService;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author zehong
 * @date 2023-11-08
 */
@Service
public class TUserInspectServiceImpl implements ITUserInspectService 
{
    @Autowired
    private TUserInspectMapper tUserInspectMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    @Override
    public TUserInspect selectTUserInspectById(Long id)
    {
        return tUserInspectMapper.selectTUserInspectById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tUserInspect 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<TUserInspect> selectTUserInspectList(TUserInspect tUserInspect)
    {
        return tUserInspectMapper.selectTUserInspectList(tUserInspect);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param tUserInspect 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertTUserInspect(TUserInspect tUserInspect)
    {
        return tUserInspectMapper.insertTUserInspect(tUserInspect);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param tUserInspect 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateTUserInspect(TUserInspect tUserInspect)
    {
        tUserInspect.setUpdateTime(DateUtils.getNowDate());
        return tUserInspectMapper.updateTUserInspect(tUserInspect);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteTUserInspectByIds(Long[] ids)
    {
        return tUserInspectMapper.deleteTUserInspectByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteTUserInspectById(Long id)
    {
        return tUserInspectMapper.deleteTUserInspectById(id);
    }
}
